@@ -6,7 +6,6 @@
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QIcon>
-#include <QObject>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QQuickStyle>
@@ -18,7 +17,7 @@
 #endif
 
 #include <KAboutData>
-#include <KLocalizedContext>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
 
 #include "version.h"
@@ -50,24 +49,19 @@ int main(int argc, char *argv[])
     QQmlApplicationEngine engine;
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("kalk"));
     parser.addVersionOption();
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+    KLocalization::setupLocalizedContext(&engine);
 
     KAboutData aboutData(QStringLiteral("kalk"),
                          i18n("Calculator"),
                          QStringLiteral(KALK_VERSION_STRING),
                          i18n("Calculator for Plasma"),
                          KAboutLicense::GPL,
-                         i18n("© 2020-2022 KDE Community"));
+                         i18n("© 2020-2024 KDE Community"));
     aboutData.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=kalk");
     KAboutData::setApplicationData(aboutData);
 
     parser.process(app);
 
-#ifdef QT_DEBUG
-    engine.rootContext()->setContextProperty(QStringLiteral("debug"), true);
-#else
-    engine.rootContext()->setContextProperty(QStringLiteral("debug"), false);
-#endif
     // load main ui
     engine.loadFromModule(u"org.kde.kalk"_s, u"Main"_s);
 
